==> kubernetes-model-storageclass-4.12.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/storage/v1beta1/CSIDriverSpecBuilder.java <==
package io.fabric8.kubernetes.api.model.storage.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class CSIDriverSpecBuilder extends CSIDriverSpecFluentImpl<CSIDriverSpecBuilder> implements VisitableBuilder<CSIDriverSpec,CSIDriverSpecBuilder> {

    CSIDriverSpecFluent<?> fluent;
    Boolean validationEnabled;

    public CSIDriverSpecBuilder() { 
        this(true);
    }


    public CSIDriverSpecBuilder(Boolean validationEnabled) { 
        this(new CSIDriverSpec(), validationEnabled);
    }


    public CSIDriverSpecBuilder(CSIDriverSpecFluent<?> fluent) { 
        this(fluent, true);
    }


    public CSIDriverSpecBuilder(CSIDriverSpecFluent<?> fluent,Boolean validationEnabled) { 
        this(fluent, new CSIDriverSpec(), validationEnabled);
    }


    public CSIDriverSpecBuilder(CSIDriverSpecFluent<?> fluent,CSIDriverSpec instance) { 
        this(fluent, instance, true);
    }


    public CSIDriverSpecBuilder(CSIDriverSpecFluent<?> fluent,CSIDriverSpec instance,Boolean validationEnabled) { 
        this.fluent = fluent; 
        fluent.withAttachRequired(instance.getAttachRequired()); 
        fluent.withPodInfoOnMount(instance.getPodInfoOnMount()); 
        fluent.withVolumeLifecycleModes(instance.getVolumeLifecycleModes()); 
        this.validationEnabled = validationEnabled; 
    }


    public CSIDriverSpecBuilder(CSIDriverSpec instance) { 
        this(instance,true);
    }


    public CSIDriverSpecBuilder(CSIDriverSpec instance,Boolean validationEnabled) { 
        this.fluent = this; 
        this.withAttachRequired(instance.getAttachRequired()); 
        this.withPodInfoOnMount(instance.getPodInfoOnMount()); 
        this.withVolumeLifecycleModes(instance.getVolumeLifecycleModes()); 
        this.validationEnabled = validationEnabled; 
    }


    public CSIDriverSpec build() {
        CSIDriverSpec buildable = new CSIDriverSpec(fluent.isAttachRequired(),fluent.isPodInfoOnMount(),fluent.getVolumeLifecycleModes());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        CSIDriverSpecBuilder that = (CSIDriverSpecBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> kubernetes-model-storageclass-5.0.2-sources.jar: annotations/io/fabric8/kubernetes/api/model/storage/v1beta1/CSIDriverSpecBuilder.java <==
package io.fabric8.kubernetes.api.model.storage.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class CSIDriverSpecBuilder extends CSIDriverSpecFluentImpl<CSIDriverSpecBuilder> implements VisitableBuilder<CSIDriverSpec,CSIDriverSpecBuilder> {

    CSIDriverSpecFluent<?> fluent;
    Boolean validationEnabled;

    public CSIDriverSpecBuilder() {
        this(true);
    }

    public CSIDriverSpecBuilder(Boolean validationEnabled) {
        this(new CSIDriverSpec(), validationEnabled);
    }

    public CSIDriverSpecBuilder(CSIDriverSpecFluent<?> fluent) {
        this(fluent, true);
    }

    public CSIDriverSpecBuilder(CSIDriverSpecFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new CSIDriverSpec(), validationEnabled);
    }

    public CSIDriverSpecBuilder(CSIDriverSpecFluent<?> fluent,CSIDriverSpec instance) {
        this(fluent, instance, true);
    }

    public CSIDriverSpecBuilder(CSIDriverSpecFluent<?> fluent,CSIDriverSpec instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withAttachRequired(instance.getAttachRequired()); 
        fluent.withFsGroupPolicy(instance.getFsGroupPolicy()); 
        fluent.withPodInfoOnMount(instance.getPodInfoOnMount()); 
        fluent.withStorageCapacity(instance.getStorageCapacity()); 
        fluent.withVolumeLifecycleModes(instance.getVolumeLifecycleModes()); 
        this.validationEnabled = validationEnabled; 
    }

    public CSIDriverSpecBuilder(CSIDriverSpec instance) {
        this(instance,true);
    }

    public CSIDriverSpecBuilder(CSIDriverSpec instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withAttachRequired(instance.getAttachRequired()); 
        this.withFsGroupPolicy(instance.getFsGroupPolicy()); 
        this.withPodInfoOnMount(instance.getPodInfoOnMount()); 
        this.withStorageCapacity(instance.getStorageCapacity()); 
        this.withVolumeLifecycleModes(instance.getVolumeLifecycleModes()); 
        this.validationEnabled = validationEnabled; 
    }

    public CSIDriverSpec build() {
        CSIDriverSpec buildable = new CSIDriverSpec(fluent.isAttachRequired(),fluent.getFsGroupPolicy(),fluent.isPodInfoOnMount(),fluent.isStorageCapacity(),fluent.getVolumeLifecycleModes());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        CSIDriverSpecBuilder that = (CSIDriverSpecBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
